[Mplayer-cvslog] CVS: main/libvo video_out.h,1.13,1.14 video_out_internal.h,1.6,1.7 vo_3dfx.c,1.8,1.9 vo_aa.c,1.17,1.18 vo_dga.c,1.36,1.37 vo_directfb.c,1.5,1.6 vo_dxr3.c,1.38,1.39 vo_fbdev.c,1.54,1.55 vo_fsdga.c,1.5,1.6 vo_ggi.c,1.11,1.12 vo_gl.c,1.16,1.17 vo_gl2.c,1.10,1.11 vo_md5.c,1.6,1.7 vo_mga.c,1.19,1.20 vo_mpegpes.c,1.16,1.17 vo_null.c,1.3,1.4 vo_odivx.c,1.7,1.8 vo_pgm.c,1.7,1.8 vo_png.c,1.8,1.9 vo_sdl.c,1.60,1.61 vo_svga.c,1.39,1.40 vo_syncfb.c,1.7,1.8 vo_tdfxfb.c,1.3,1.4 vo_vesa.c,1.56,1.57 vo_x11.c,1.49,1.50 vo_xmga.c,1.40,1.41 vo_xv.c,1.46,1.47 vo_xvidix.c,1.11,1.12 vo_zr.c,1.4,1.5 vosub_vidix.h,1.6,1.7

Nick Kurshev nick at mplayer.dev.hu
Sat Jan 26 17:01:29 CET 2002


Update of /cvsroot/mplayer/main/libvo
In directory mplayer:/var/tmp.root/cvs-serv3891

Modified Files:
	video_out.h video_out_internal.h vo_3dfx.c vo_aa.c vo_dga.c 
	vo_directfb.c vo_dxr3.c vo_fbdev.c vo_fsdga.c vo_ggi.c vo_gl.c 
	vo_gl2.c vo_md5.c vo_mga.c vo_mpegpes.c vo_null.c vo_odivx.c 
	vo_pgm.c vo_png.c vo_sdl.c vo_svga.c vo_syncfb.c vo_tdfxfb.c 
	vo_vesa.c vo_x11.c vo_xmga.c vo_xv.c vo_xvidix.c vo_zr.c 
	vosub_vidix.h 
Log Message:
Extensions for video accelerated architecture

Index: video_out_internal.h
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/video_out_internal.h,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- video_out_internal.h	13 Aug 2001 11:33:34 -0000	1.6
+++ video_out_internal.h	26 Jan 2002 16:01:26 -0000	1.7
@@ -30,9 +30,12 @@
 static void check_events(void);
 static void uninit(void);
 static uint32_t query_format(uint32_t format);
+static uint32_t preinit(const char *);
+static void query_vaa(vo_vaa_t *);
 
 #define LIBVO_EXTERN(x) vo_functions_t video_out_##x =\
 {\
+	preinit,\
 	init,\
         query_format,\
 	get_info,\
@@ -42,6 +45,7 @@
 	flip_page,\
 	check_events,\
 	uninit,\
+	query_vaa\
 };
 
 #include "osd.h"

Index: vo_3dfx.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_3dfx.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- vo_3dfx.c	27 Sep 2001 12:22:27 -0000	1.8
+++ vo_3dfx.c	26 Jan 2002 16:01:26 -0000	1.9
@@ -488,4 +488,13 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}
 

Index: vo_aa.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_aa.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- vo_aa.c	19 Jan 2002 17:01:48 -0000	1.17
+++ vo_aa.c	26 Jan 2002 16:01:26 -0000	1.18
@@ -752,3 +752,12 @@
     aaopt_subcolor= AA_SPECIAL;
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_dga.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_dga.c,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -r1.36 -r1.37
--- vo_dga.c	8 Jan 2002 20:58:53 -0000	1.36
+++ vo_dga.c	26 Jan 2002 16:01:26 -0000	1.37
@@ -23,8 +23,8 @@
  * - works only on x86 architectures
  *
  * $Log$
- * Revision 1.36  2002/01/08 20:58:53  atmos4
- * SwScaler support for vo_png by Kim Minh, SwScale w/aspecz for vo_dga by me
+ * Revision 1.37  2002/01/26 16:01:26  nick
+ * Extensions for video accelerated architecture
  *
  * Revision 1.35  2001/12/28 20:52:54  alex
  * use XF86VidMode later in init (at line 1031) only if we've got support (if have_vm==1)
@@ -1173,6 +1173,16 @@
   vd_printf(VD_INFO, "vo_dga: Doublebuffering is %s.\n", vo_dga_dbf_mem_offset ? "enabled" : "disabled");
   vo_dga_is_running = 1;
   return 0;
+}
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
 }
 
 //---------------------------------------------------------

Index: vo_directfb.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_directfb.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- vo_directfb.c	22 Dec 2001 00:28:49 -0000	1.5
+++ vo_directfb.c	26 Jan 2002 16:01:26 -0000	1.6
@@ -888,3 +888,12 @@
 
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_dxr3.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_dxr3.c,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -r1.38 -r1.39
--- vo_dxr3.c	19 Jan 2002 22:24:30 -0000	1.38
+++ vo_dxr3.c	26 Jan 2002 16:01:26 -0000	1.39
@@ -551,3 +551,13 @@
 static void check_events(void)
 {
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_fbdev.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_fbdev.c,v
retrieving revision 1.54
retrieving revision 1.55
diff -u -r1.54 -r1.55
--- vo_fbdev.c	17 Jan 2002 01:15:31 -0000	1.54
+++ vo_fbdev.c	26 Jan 2002 16:01:26 -0000	1.55
@@ -1338,3 +1338,12 @@
 #endif
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_fsdga.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_fsdga.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- vo_fsdga.c	6 Nov 2001 11:21:08 -0000	1.5
+++ vo_fsdga.c	26 Jan 2002 16:01:26 -0000	1.6
@@ -463,8 +463,12 @@
 }
 #endif
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
-
-
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_ggi.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_ggi.c,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- vo_ggi.c	6 Nov 2001 11:21:08 -0000	1.11
+++ vo_ggi.c	26 Jan 2002 16:01:26 -0000	1.12
@@ -765,3 +765,13 @@
     }
     return;
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_gl.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_gl.c,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -r1.16 -r1.17
--- vo_gl.c	6 Jan 2002 21:07:20 -0000	1.16
+++ vo_gl.c	26 Jan 2002 16:01:26 -0000	1.17
@@ -477,3 +477,13 @@
   saver_on(mDisplay); // screen saver back on
   XDestroyWindow( mDisplay,mywindow );
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_gl2.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_gl2.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- vo_gl2.c	6 Jan 2002 21:07:20 -0000	1.10
+++ vo_gl2.c	26 Jan 2002 16:01:26 -0000	1.11
@@ -1103,3 +1103,13 @@
   saver_on(mDisplay); // screen saver back on
   XDestroyWindow( mDisplay,mywindow );
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_md5.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_md5.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- vo_md5.c	13 Aug 2001 11:08:18 -0000	1.6
+++ vo_md5.c	26 Jan 2002 16:01:26 -0000	1.7
@@ -103,4 +103,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_mga.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_mga.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- vo_mga.c	21 Oct 2001 21:12:00 -0000	1.19
+++ vo_mga.c	26 Jan 2002 16:01:26 -0000	1.20
@@ -146,5 +146,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_mpegpes.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_mpegpes.c,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -r1.16 -r1.17
--- vo_mpegpes.c	24 Jan 2002 18:59:06 -0000	1.16
+++ vo_mpegpes.c	26 Jan 2002 16:01:26 -0000	1.17
@@ -511,3 +511,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_null.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_null.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- vo_null.c	13 Aug 2001 11:08:18 -0000	1.3
+++ vo_null.c	26 Jan 2002 16:01:26 -0000	1.4
@@ -90,5 +90,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_odivx.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_odivx.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- vo_odivx.c	13 Aug 2001 11:33:34 -0000	1.7
+++ vo_odivx.c	26 Jan 2002 16:01:26 -0000	1.8
@@ -261,10 +261,16 @@
 {
 }
 
-
-
 static void check_events(void)
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_pgm.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_pgm.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- vo_pgm.c	13 Aug 2001 11:33:34 -0000	1.7
+++ vo_pgm.c	26 Jan 2002 16:01:26 -0000	1.8
@@ -135,5 +135,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_png.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_png.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- vo_png.c	8 Jan 2002 20:58:53 -0000	1.8
+++ vo_png.c	26 Jan 2002 16:01:26 -0000	1.9
@@ -309,3 +309,13 @@
 static void check_events(void)
 {
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_sdl.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_sdl.c,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -r1.60 -r1.61
--- vo_sdl.c	24 Jan 2002 21:46:57 -0000	1.60
+++ vo_sdl.c	26 Jan 2002 16:01:26 -0000	1.61
@@ -1263,3 +1263,13 @@
 #endif
 	sdl_close();
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_svga.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_svga.c,v
retrieving revision 1.39
retrieving revision 1.40
diff -u -r1.39 -r1.40
--- vo_svga.c	18 Nov 2001 19:47:58 -0000	1.39
+++ vo_svga.c	26 Jan 2002 16:01:26 -0000	1.40
@@ -569,3 +569,13 @@
        free(list);
   }
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_syncfb.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_syncfb.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- vo_syncfb.c	22 Aug 2001 20:14:10 -0000	1.7
+++ vo_syncfb.c	26 Jan 2002 16:01:26 -0000	1.8
@@ -448,3 +448,12 @@
 {
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_tdfxfb.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_tdfxfb.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- vo_tdfxfb.c	6 Nov 2001 11:21:08 -0000	1.3
+++ vo_tdfxfb.c	26 Jan 2002 16:01:26 -0000	1.4
@@ -823,4 +823,12 @@
 }
 #endif /* ! HWACCEL_OSD_M2 */
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_vesa.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_vesa.c,v
retrieving revision 1.56
retrieving revision 1.57
diff -u -r1.56 -r1.57
--- vo_vesa.c	16 Jan 2002 15:22:45 -0000	1.56
+++ vo_vesa.c	26 Jan 2002 16:01:26 -0000	1.57
@@ -988,3 +988,13 @@
         printf("vo_vesa: check_events was called\n");
 /* Nothing to do */
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_x11.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_x11.c,v
retrieving revision 1.49
retrieving revision 1.50
diff -u -r1.49 -r1.50
--- vo_x11.c	24 Jan 2002 18:13:54 -0000	1.49
+++ vo_x11.c	26 Jan 2002 16:01:26 -0000	1.50
@@ -614,5 +614,12 @@
 printf("vo: uninit!\n");
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_xmga.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_xmga.c,v
retrieving revision 1.40
retrieving revision 1.41
diff -u -r1.40 -r1.41
--- vo_xmga.c	23 Jan 2002 15:16:20 -0000	1.40
+++ vo_xmga.c	26 Jan 2002 16:01:26 -0000	1.41
@@ -391,3 +391,13 @@
  mga_uninit();
  printf("vo: uninit!\n");
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_xv.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_xv.c,v
retrieving revision 1.46
retrieving revision 1.47
diff -u -r1.46 -r1.47
--- vo_xv.c	26 Jan 2002 15:46:58 -0000	1.46
+++ vo_xv.c	26 Jan 2002 16:01:26 -0000	1.47
@@ -610,5 +610,12 @@
  for( i=0;i<num_buffers;i++ ) deallocate_xvimage( i );
 }
 
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
 
-
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_xvidix.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_xvidix.c,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- vo_xvidix.c	23 Jan 2002 15:16:20 -0000	1.11
+++ vo_xvidix.c	26 Jan 2002 16:01:26 -0000	1.12
@@ -490,3 +490,13 @@
 
     return;
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vo_zr.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_zr.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- vo_zr.c	26 Jan 2002 00:53:29 -0000	1.4
+++ vo_zr.c	26 Jan 2002 16:01:26 -0000	1.5
@@ -604,3 +604,13 @@
     norm = VIDEO_MODE_AUTO;
 
 }
+
+static uint32_t preinit(const char *arg)
+{
+  return 0;
+}
+
+static void query_vaa(vo_vaa_t *vaa)
+{
+  memset(vaa,0,sizeof(vo_vaa_t));
+}

Index: vosub_vidix.h
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vosub_vidix.h,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- vosub_vidix.h	19 Jan 2002 16:58:33 -0000	1.6
+++ vosub_vidix.h	26 Jan 2002 16:01:26 -0000	1.7
@@ -1,37 +1,37 @@
-/*
- *  vosub_vidix.h
- *
+/*
+ *  vosub_vidix.h
+ *
  *	Copyright (C) Nick Kurshev <nickols_k at mail.ru> - 2002
- *
- *  You can redistribute this file under terms and conditions
- *  of GNU General Public licence v2.
- *
- * This file contains vosub_vidix interface to any mplayer's VO driver
- */
-
-#ifndef __VOSUB_VIDIX_INCLUDED
-#define __VOSUB_VIDIX_INCLUDED
+ *
+ *  You can redistribute this file under terms and conditions
+ *  of GNU General Public licence v2.
+ *
+ * This file contains vosub_vidix interface to any mplayer's VO driver
+ */
+
+#ifndef __VOSUB_VIDIX_INCLUDED
+#define __VOSUB_VIDIX_INCLUDED
 
 		    /* drvname can be NULL */
-int	 vidix_preinit(
const char *drvname,void *server);
-int      vidix_init(unsigned src_width,unsigned src_height,
-		    unsigned dest_x,unsigned dest_y,unsigned dst_width,
+int	 vidix_preinit(const char *drvname,void *server);
+int      vidix_init(unsigned src_width,unsigned src_height,
+		    unsigned dest_x,unsigned dest_y,unsigned dst_width,
 		    unsigned dst_height,unsigned format,unsigned dest_bpp,
-		    unsigned vid_w,unsigned vid_h);
+		    unsigned vid_w,unsigned vid_h);
 int	 vidix_start(void);
 int	 vidix_stop(void);
-void     vidix_term( void );
-uint32_t vidix_query_fourcc(unsigned fourcc);
-
-uint32_t vidix_draw_slice(uint8_t *image[], int stride[], int w,int h,int x,int y);
-uint32_t vidix_draw_frame(uint8_t *src[]);
-void     vidix_flip_page(void);
-void     vidix_draw_osd(void);
+void     vidix_term( void );
+uint32_t vidix_query_fourcc(unsigned fourcc);
+
+uint32_t vidix_draw_slice(uint8_t *image[], int stride[], int w,int h,int x,int y);
+uint32_t vidix_draw_frame(uint8_t *src[]);
+void     vidix_flip_page(void);
+void     vidix_draw_osd(void);
 
 #include "../vidix/vidix.h"
 /* graphic keys */
 int vidix_grkey_support(void);
 int vidix_grkey_get(vidix_grkey_t *gr_key);
 int vidix_grkey_set(const vidix_grkey_t *gr_key);
-
-#endif
+
+#endif




More information about the MPlayer-cvslog mailing list
Index: video_out.h
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/video_out.h,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- video_out.h	29 Nov 2001 17:31:58 -0000	1.13
+++ video_out.h	26 Jan 2002 16:01:26 -0000	1.14
@@ -10,6 +10,7 @@
 
 #include "font_load.h"
 #include "img_format.h"
+#include "../vidix/vidix.h"
 
 #define VO_EVENT_EXPOSE 1
 #define VO_EVENT_RESIZE 2
@@ -27,10 +28,53 @@
         const char *comment;
 } vo_info_t;
 
+/* Direct access to BES */
+typedef struct bes_da_s
+{
+	vidix_rect_t	dest;           /* This field should be filled by x,y,w,h
+					   from vidix:src but pitches from
+					   vidix:dest */
+	int		flags;          /* Probably will work only when flag == 0 */
+	/* memory model */
+	unsigned	frame_size;		/* destinition frame size */
+	unsigned	num_frames;		/* number available frames */
+	unsigned	offsets[VID_PLAY_MAXFRAMES]; /* relative offset of each frame from begin of video memory */
+	vidix_yuv_t	offset;			/* relative offsets within frame for yuv planes */
+	void*		dga_addr;		/* linear address of BES */
+}bes_da_t;
+
+/*
+   Video Accelearted Architecture.
+   Every field of this structure can be set to NULL that means that
+   features is not supported
+*/
+typedef struct vo_vaa_s
+{
+	uint32_t    flags; /* currently undefined */
+		/*
+		 * Query Direct Access to BES
+		 * info - information to be filled
+		 * returns: 0 on success errno on error.
+		 */
+	int  (*query_bes_da)(bes_da_t *info);
+	int  (*get_video_eq)(vidix_video_eq_t *info);
+	int  (*set_video_eq)(const vidix_video_eq_t *info);
+	int  (*get_num_fx)(unsigned *info);
+	int  (*get_oem_fx)(vidix_oem_fx_t *info);
+	int  (*set_oem_fx)(const vidix_oem_fx_t *info);
+	int  (*set_deint)(const vidix_deinterlace_t *info);
+}vo_vaa_t;
+
 typedef struct vo_functions_s
 {
+	/*
+	 * Preinitializes driver (real INITIALIZATION)
+	 *   arg - currently it's vo_subdevice
+	 *   returns: zero on successful initialization, non-zero on error.
+	 */
+	uint32_t (*preinit)(const char *arg);
         /*
          * Initialize the display driver.
 	 * params:
          *   width,height: image source size
 	 *   d_width,d_height: size of the requested window size, just a hint
@@ -92,6 +136,14 @@
          * Closes driver. Should restore the original state of the system.
          */
         void (*uninit)(void);
+
+	/*
+	 * Query Video Accelerated Architecture information.
+	 * params:
+	 *   vaa: address of struct to be filled.
+	 *  (Note: driver should memset it to ZERO if it doesn't support vaa.)
+	 */
+	void (*query_vaa)(vo_vaa_t *vaa);
 
 } vo_functions_t;
 
@@ -27,10 +28,53 @@
         /*
-         * Initialize the display driver.
+         * Initialize (means CONFIGURE) the display driver.
 	 * params:
          *   width,height: image source size
